@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Redis;
 use List::MoreUtils qw( bsearch );
@@ -384,9 +384,10 @@ sub _route {
   my $cmd_name = shift;
   my $args     = shift;
 
-  if ( $self->{refresh_interval} > 0
+  if ( !defined $self->{_slots} || (
+    $self->{refresh_interval} > 0
     && Time::HiRes::tv_interval( $self->{_refresh_timestamp} )
-        > $self->{refresh_interval} )
+        > $self->{refresh_interval} ) )
   {
     $self->_init;
   }
