@@ -48,6 +48,8 @@ BEGIN {
     client_getname  => 'test',
   );
 
+  our @mock_keys = qw( key1 key2 key3 key4 key5 );
+
   Test::MockObject->fake_module( 'Redis',
     new => sub {
       my $class  = shift;
@@ -71,6 +73,12 @@ BEGIN {
         }
       );
 
+      $mock->mock( 'keys',
+        sub {
+          return @mock_keys;
+        }
+      );
+
       return $mock;
     },
   );
